pub struct Component {
pub id: ComponentId,
/* private fields */
}Expand description
The unit of composition for the gear object model. A component consists of one or more objects. Each object implements one or more traits. Component clients are only allowed to interact with objects via their traits. Note that publicly released traits should be treated as immutable to foster backward compatibility.
Fields
id: ComponentIdImplementations